/*
 * Copyright 2005, 2006 University of Leiden.
 *
 * This file is part of MIA+EWS.
 *
 * MIA+EWS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MIA+EWS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MIA; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/*******************************************************************************
* E.S.O. - VLT project
*
* "@(#) $Id: fourg.h,v 1.4 2002/05/08 21:24:47 jdejong Exp $"
*
* who       when      what
* --------  --------  ----------------------------------------------
* jdejong 2002-05-08  imported
*/

/************************************************************************
 *
 *----------------------------------------------------------------------
 */

/* $Id: fourg.h,v 1.4 2002/05/08 21:24:47 jdejong Exp $ */

/*-----------------------------------------------------------------------
 *     Cooley-Tukey fast fourier transform.
 *     One-dimensional transform of complex data, arbitrary number of
 *     points.  N points can be transformed in time proportional to
 *     N*log(N) (for N non-prime), whereas other methods take N**2 time.
 *     furthermore, because fewer arithmetic operations are performed,
 *     less error is built up.
 *     The transform done is--
 *           Real*4 data(n),transform(n),work(n)
 *            *omplex data,transform,work
 *       transform(k) = sum(data(j)*exp(isign*2*pi*i*(j-1)*(k-1)/n)),
 *     summed from j = 1 to n for all k from 1 to N.  The transform
 *     values are returned to data, replacing the input.  N may be any
 *     positive number, but it should be non-prime for speed.
 *     ISIGN = +1 or -1.
 *     A -1 transform followed by a +1 one (or vice versa)
 *     returns n times the original data.  work is a one-dimensional
 *     complex array of length n used for working storage.
 *     running time is proportional to n * (sum of the prime factors of
 *     n).  for example, n = 1960, time is to * 1960 * (2+2+2+5+7+7).
 *     naive methods directly implementing the summation run in time
 *     proportional to n**2.  an upper bound for the rms relative error
 *     is 3 * 2**(-b) * sum(f**1.5), where b is the number of bits in
 *     the floating point fraction and the sum is over the prime
 *     factors of n.
 *
 *  Inputs:
 *     data      Array of length N to be FFT'd
 *     n         Length of data array - need not be a power of two.
 *     isign     Direction of transform
 *     work      Array of length N for temporary storage.
 *
 *  Outputs:
 *     data      Transformed array
 *
 *     Written by Norman Brenner, Mit, August 1968.
 *     Converted to c by W. D. Cotton, October 1999.
 *---------------------------------------------------------------------*/
#ifndef FOURG_H
#define FOURG_H
void fourg (float *data, int n, int isign, float *work);
#endif  /* FOURG_H */
/* */
